aboutsummaryrefslogtreecommitdiffstats
path: root/activerecord/lib/active_record
diff options
context:
space:
mode:
authorSean Griffin <sean@seantheprogrammer.com>2015-10-20 14:20:32 -0600
committerSean Griffin <sean@seantheprogrammer.com>2015-10-20 14:20:32 -0600
commit8b64aba17bbb7bc6af6f0aafb874904147f373bf (patch)
tree046a807b6ad660e25424d8dbf608e834e86be6db /activerecord/lib/active_record
parentcbcdecd2c55fca9613722779231de2d8dd67ad02 (diff)
parent86d2924a115c2604e4facdf285a7b764938fae0f (diff)
downloadrails-8b64aba17bbb7bc6af6f0aafb874904147f373bf.tar.gz
rails-8b64aba17bbb7bc6af6f0aafb874904147f373bf.tar.bz2
rails-8b64aba17bbb7bc6af6f0aafb874904147f373bf.zip
Merge pull request #21883 from tarzan/cache-key-too-precise
Fix precision on cache_key
Diffstat (limited to 'activerecord/lib/active_record')
-rw-r--r--activerecord/lib/active_record/integration.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/activerecord/lib/active_record/integration.rb b/activerecord/lib/active_record/integration.rb
index 19d2589db3..466c8509a4 100644
--- a/activerecord/lib/active_record/integration.rb
+++ b/activerecord/lib/active_record/integration.rb
@@ -10,9 +10,9 @@ module ActiveRecord
# Indicates the format used to generate the timestamp in the cache key.
# Accepts any of the symbols in <tt>Time::DATE_FORMATS</tt>.
#
# This is +:nsec+, by default.
class_attribute :cache_timestamp_format, :instance_writer => false
- self.cache_timestamp_format = :nsec
+ self.cache_timestamp_format = :usec
end
# Returns a String, which Action Pack uses for constructing a URL to this
@@ -10,9 +10,9 @@ module ActiveRecord
# Accepts any of the symbols in <tt>Time::DATE_FORMATS</tt>.
#
- # This is +:nsec+, by default.
+ # This is +:usec+, by default.
class_attribute :cache_timestamp_format, :instance_writer => false